@@ -211,7 +211,7 @@ class MassFunctions:
         k_grid = np.concatenate([k_grid_1, k_grid_2])
         int_ans = np.zeros_like(M)
         for i in range(len(k_grid)-1):
-            int_ans = quad_vec(self.dsigma2_dlnk,np.log(k_grid[i]),np.log(k_grid[i+1]), args=(M,),epsrel=precision,limit=200)[0]
+            int_ans += quad_vec(self.dsigma2_dlnk,np.log(k_grid[i]),np.log(k_grid[i+1]), args=(M,),epsrel=precision,limit=200)[0]
         return int_ans
 
     def dsigma2_dlnk_dm(self,lnk,M):
@@ -225,8 +225,8 @@ class MassFunctions:
 
     def dsigma2_dm(self,M):
         precision = 1e-6
-        k_grid_1 = np.logspace(-4,0.9,20)
-        k_grid_2 = np.logspace(1,8,150)
+        k_grid_1 = np.logspace(-4,0.9,100)
+        k_grid_2 = np.logspace(1,8,200)
         k_grid = np.concatenate([k_grid_1, k_grid_2])
         int_ans = np.zeros_like(M)
         for i in range(len(k_grid)-1):
