@@ -29,54 +29,54 @@ class Barrier:
         self.ratio = self.Modify_Ratio()  # Ratio for partial ionization
     
     def Nion_Pure(self,Mv,deltaR):
-        def Nion_Pure_diff(m):
+        def Nion_Pure_diff(m,Mv,deltaR):
             fstar = cosmo.fstar(m)
-            return fstar*m*self.dndmeps(m,Mv,deltaR,self.z)
+            return fstar*m*self.dndmeps(m,Mv,deltaR,self.z)/ m_H * omega_b / omega_m
         mslice = np.logspace(np.log10(self.M_min), np.log10(Mv), 12)
         ans = np.zeros_like(deltaR)
         for i in range(len(mslice)-1):
-            ans += quad_vec(Nion_Pure_diff, mslice[i], mslice[i+1],args=(Mv,deltaR), epsrel=1e-6,)[0]
+            ans += quad_vec(Nion_Pure_diff, mslice[i], mslice[i+1],args=(Mv,deltaR), epsrel=1e-6)[0]
         return ans
     
     def Nxi_Pure(self,Mv,deltaR):
-        def Nxi_Pure_diff(m):
-            return m*self.dndmeps(m,Mv,deltaR,self.z)
+        def Nxi_Pure_diff(m,Mv,deltaR):
+            return m*self.dndmeps(m,Mv,deltaR,self.z)/ m_H * omega_b / omega_m
         mslice = np.logspace(np.log10(self.M_J), np.log10(self.M_min), 12)
         ans = np.zeros_like(deltaR)
         for i in range(len(mslice)-1):
-            ans += quad_vec(Nxi_Pure_diff, mslice[i], mslice[i+1],args=(Mv,deltaR), epsrel=1e-6,)[0]
+            ans += quad_vec(Nxi_Pure_diff, mslice[i], mslice[i+1],args=(Mv,deltaR), epsrel=1e-6)[0]
         return ans
 
     # Interpolation for Nion
     def Nion_interp(self, Mv,deltaR):
         try:
-            Nion_arr = np.load(f'.Nion_Nxi_init/Nion_arr_Mv_{Mv:.3f}at_z={self.z:.2f}_A{self.A2byA1}_k{self.kMpc_trans}_alpha{self.alpha}_beta{self.beta}.npy')
+            Nion_arr = np.load(f'.Nion_Interp_init/NionAtz{self.z:.2f}/Nion_arr_Mv_{Mv:.3f}at_z={self.z:.2f}_A{self.A2byA1}_k{self.kMpc_trans}_alpha{self.alpha}_beta{self.beta}.npy')
         except FileNotFoundError:
-            os.makedirs('.Nion_Nxi_init', exist_ok=True)
+            os.makedirs(f'.Nion_Interp_init/NionAtz{self.z:.2f}', exist_ok=True)
             nion_pure = self.Nion_Pure(Mv, self.deltaR_interp)
-            np.save(f'.Nion_Nxi_init/Nion_arr_Mv_{Mv:.3f}at_z={self.z:.2f}_A{self.A2byA1}_k{self.kMpc_trans}_alpha{self.alpha}_beta{self.beta}.npy', nion_pure)
-            Nion_arr = np.load(f'.Nion_Nxi_init/Nion_arr_Mv_{Mv:.3f}at_z={self.z:.2f}_A{self.A2byA1}_k{self.kMpc_trans}_alpha{self.alpha}_beta{self.beta}.npy')
+            np.save(f'.Nion_Interp_init/NionAtz{self.z:.2f}/Nion_arr_Mv_{Mv:.3f}at_z={self.z:.2f}_A{self.A2byA1}_k{self.kMpc_trans}_alpha{self.alpha}_beta{self.beta}.npy', nion_pure)
+            Nion_arr = np.load(f'.Nion_Interp_init/NionAtz{self.z:.2f}/Nion_arr_Mv_{Mv:.3f}at_z={self.z:.2f}_A{self.A2byA1}_k{self.kMpc_trans}_alpha{self.alpha}_beta{self.beta}.npy')
         self.Nion_interp_Mv = interp1d(self.deltaR_interp, Nion_arr, kind='cubic')
-        return self.Nion_interp_Mv(deltaR) * self.fesc * self.qion / m_H * omega_b / omega_m
+        return self.Nion_interp_Mv(deltaR) * self.fesc * self.qion 
 
     # Interpolation for N_xi
     def N_xi_interp(self, Mv, deltaR):
         try:
-            Nxi_arr = np.load(f'.Nion_Nxi_init/Nxi_arr_Mv_{Mv:.3f}at_z={self.z:.2f}_A{self.A2byA1}_k{self.kMpc_trans}_alpha{self.alpha}_beta{self.beta}.npy')
+            Nxi_arr = np.load(f'.Nxi_Interp_init/NxiAtz{self.z:.2f}/Nxi_arr_Mv_{Mv:.3f}at_z={self.z:.2f}_A{self.A2byA1}_k{self.kMpc_trans}_alpha{self.alpha}_beta{self.beta}.npy')
         except FileNotFoundError:
-            os.makedirs('.Nion_Nxi_init', exist_ok=True)
+            os.makedirs(f'.Nxi_Interp_init/NxiAtz{self.z:.2f}', exist_ok=True)
             nxi_pure = self.Nxi_Pure(Mv, self.deltaR_interp)
-            np.save(f'.Nion_Nxi_init/Nxi_arr_Mv_{Mv:.3f}at_z={self.z:.2f}_A{self.A2byA1}_k{self.kMpc_trans}_alpha{self.alpha}_beta{self.beta}.npy', nxi_pure)
-            Nxi_arr = np.load(f'.Nion_Nxi_init/Nxi_arr_Mv_{Mv:.3f}at_z={self.z:.2f}_A{self.A2byA1}_k{self.kMpc_trans}_alpha{self.alpha}_beta{self.beta}.npy')
+            np.save(f'.Nxi_Interp_init/NxiAtz{self.z:.2f}/Nxi_arr_Mv_{Mv:.3f}at_z={self.z:.2f}_A{self.A2byA1}_k{self.kMpc_trans}_alpha{self.alpha}_beta{self.beta}.npy', nxi_pure)
+            Nxi_arr = np.load(f'.Nxi_Interp_init/NxiAtz{self.z:.2f}/Nxi_arr_Mv_{Mv:.3f}at_z={self.z:.2f}_A{self.A2byA1}_k{self.kMpc_trans}_alpha{self.alpha}_beta{self.beta}.npy')
         self.Nxi_interp_Mv = interp1d(self.deltaR_interp, Nxi_arr, kind='cubic')
-        return self.Nxi_interp_Mv(deltaR) * self.xi / m_H * omega_b / omega_m
+        return self.Nxi_interp_Mv(deltaR) * self.xi 
 
     #patch
     def Nion_ST(self):
         def Nion_ST_diff(m):
             fstar = cosmo.fstar(m)
-            return (fstar * m * self.powspec.dndmst(m, self.z))
-        mslice = np.logspace(np.log10(self.M_min), np.log10(cosmo.M_vir(0.61,1e8,self.z)), 30)
+            return (1 / m_H * fstar * omega_b / omega_m * m * self.powspec.dndmst(m, self.z))
+        mslice = np.logspace(np.log10(self.M_min), np.log10(cosmo.M_vir(0.61,1e8,self.z)), 100)
         ans = 0
         for i in range(len(mslice)-1):
             ans += quad(Nion_ST_diff, mslice[i], mslice[i+1], epsrel=1e-7)[0]
@@ -85,20 +85,20 @@ class Barrier:
     def Nion_PS(self):
         def Nion_PS_diff(m):
             fstar = cosmo.fstar(m)
-            return (fstar * m * self.powspec.dndmps(m, self.z))
-        mslice = np.logspace(np.log10(self.M_min), np.log10(cosmo.M_vir(0.61,1e8,self.z)), 30)
+            return (1 / m_H * fstar * omega_b / omega_m * m * self.powspec.dndmps(m, self.z))
+        mslice = np.logspace(np.log10(self.M_min), np.log10(cosmo.M_vir(0.61,1e8,self.z)), 100)
         ans = 0
         for i in range(len(mslice)-1):
             ans += quad(Nion_PS_diff, mslice[i], mslice[i+1], epsrel=1e-7)[0]
         return ans
-
+ 
     def Modify_Ratio(self):
         try:
-            ratio = np.load(f'.Nion_Nxi_init/ratio_at_z{self.z:.2f}_A{self.A2byA1}_k{self.kMpc_trans}_alpha{self.alpha}_beta{self.beta}.npy')
+            ratio = np.load(f'.ratio_init/ratio_at_z{self.z:.2f}_A{self.A2byA1}_k{self.kMpc_trans}_alpha{self.alpha}_beta{self.beta}.npy')
         except FileNotFoundError:
-            os.makedirs('.Nion_Nxi_init', exist_ok=True)
+            os.makedirs('.ratio_init', exist_ok=True)
             ratio = self.Nion_ST() / self.Nion_PS()
-            np.save(f'.Nion_Nxi_init/ratio_at_z{self.z:.2f}_A{self.A2byA1}_k{self.kMpc_trans}_alpha{self.alpha}_beta{self.beta}.npy', ratio)
+            np.save(f'.ratio_init/ratio_at_z{self.z:.2f}_A{self.A2byA1}_k{self.kMpc_trans}_alpha{self.alpha}_beta{self.beta}.npy', ratio)
         return ratio
 
     def delta_L(self, deltar):
